@@ -68,12 +68,21 @@ def _del_jos_xprofiles(db, uidNumber):
 	db.execQuery(sql, data)
 
 
-def _insert_jos_users(db, name, username, email, jgid, jgidNumber):
-	
-	sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
-	sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-	data = (name, username, email, 'NOPASSWORD', jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
-	userID = db.execInsertQuery(sql, data)
+def _insert_jos_users(db, joomlauserid, name, username, email, pw, jgid, jgidNumber):
+
+	pwhash = hubzero.config.passwords.MD5PasswordHash(pw)
+
+	if joomlauserid == -1:
+		sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+		data = (name, username, email, pwhash , jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+		userID = db.execInsertQuery(sql, data)
+	else:
+		sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
+		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
+		data = (joomlauserid, name, username, email, pwhash, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+		userID = db.execInsertQuery(sql, data)
+
 	return userID
 
 
@@ -214,7 +223,7 @@ def _delete_ldap_user(username):
 def delhubgroup(groupName):
 	# grab config options
 	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", dbPW, "myhub")
+	db =  hubzero.data.db.mySql("localhost", "myhub", "myhub", dbPW)
 	_del_ldap_group(groupName)
 	_del_jos_xgroups(db, groupName)
 
@@ -231,24 +240,29 @@ def addhubgroup(groupName):
 	_add_ldap_group(groupName, groupName, gidNumber)
 	
 	
-def addhubuser(username, fname, lname, email, joomlagid, joomlagidNumber, gid, gidNumber):
+def addhubuser(username, fname, lname, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, joomlauserid, skipldap):
 	# grab config options
-	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", dbPW, "myhub")
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	
+	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
 	
 	fullname = fname + ' ' + lname
 
-	userID = _insert_jos_users(db, fullname, username, email, joomlagid, joomlagidNumber)
+	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
 	_insert_jos_xprofiles(db, userID, fname, lname, username, email, joomlagid, joomlagidNumber, gid, gidNumber)
-	_add_ldap_user(username, 'nopasswd')
+	
+	if not skipldap:
+		_add_ldap_user(username, 'nopasswd')
 
 	
 def delhubuser(username):
 	# grab config options
 	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", dbPW, "myhub")
+	db =  hubzero.data.db.mySql("localhost", "myhub", "myhub", dbPW)
 	
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
